==> Izmon-0.1.1-py3-none-any.whl: Izmon/Class/Basic/Settings.py <==
class Settings:
	#バージョン
	VERSION = '0.1.1'
	
	#イズモンの数
	IZ_NUM = 80

	#イズモン設定一覧
	IZUMON_SETTING = [[1 , "サーファー", 0, 162, 80, 115, 153, 111, 0.4, 0], [2 , "キョーリュー", 0, 166, 154, 115, 120, 120, 0.2, 0],
					[3 , "ササントラ", 1, 167, 125, 110, 145, 110, 0.2, 0], [4 , "トラパルト", 2, 163, 140, 95, 120, 95, 0.2, 0],
					[5 , "マルルリ", 4, 175, 70, 100, 80, 100, 1, 0], [6 , "アーマー", 1, 173, 107, 125, 73, 105, 0.6, 0],
					[7 , "カブリアス", 0, 183, 150, 115, 100, 105, 0.1, 0], [8 , "マスダ", 4, 151, 130, 90, 101, 90, 0.4, 0],
					[9 , "ラウドホーン", 1, 179, 95, 120, 130, 95, 0.4, 0], [10 , "タイガイデヌ", 4, 145, 90, 80, 125, 80, 0.6, 0],
					[11 , "バッシュドラ", 0, 183, 132, 138, 88, 92, 0.4, 0], [12 , "プロキシー", 1, 170, 85, 130, 80, 150, 0.4, 0],
					[13 , "スプラッシュドラゴン", 3, 151, 167, 110, 80, 90, 0.4, 0], [14 , "ブラストロッキー", 2, 190, 165, 112, 95, 106, 0.2, 0],
					[15 , "マーダードラゴン", 1, 165, 120, 90, 130, 170, 0.2, 0], [16 , "スカイスパロー", 0, 178, 113, 87, 91, 81, 0.6, 0],
					[17 , "ファイアウォール", 4, 153, 101, 170, 94, 89, 0.4, 0], [18 , "バブルボーラー", 0, 135, 70, 90, 100, 100, 0.6, 0],
					[19 , "バニージャンプ", 0, 145, 100, 110, 90, 100, 0.6, 0], [20 , "スノースクーパー", 1, 136, 95, 120, 105, 120, 0.6, 0],
					[21 , "ラビットフライ", 0, 155, 115, 80, 90, 85, 0.6, 0], [22 , "スピードスター", 1, 135, 100, 95, 84, 70, 0.6, 0],
					[23 , "フライングホッパー", 1, 115, 110, 90, 100, 80, 0.8, 0], [24 , "スターフレイム", 1, 177, 71, 122, 141, 150, 0.4, 0],
					[25 , "プラネットポッター", 3, 138, 89, 109, 103, 115, 0.6, 0], [26 , "バイオレーサー", 2, 185, 79, 128, 149, 78, 0.4, 0],
					[27 , "スプラッシュファイター", 1, 186, 93, 83, 98, 116, 0.6, 0], [28 , "パルネアス", 4, 165, 140, 122, 112, 129, 0.1, 0],
					[29 , "ギガヴォルテック", 3, 178, 115, 132, 81, 124, 0.2, 0], [30 , "エンペラースライム", 4, 143, 78, 89, 106, 101, 0.8, 0],
					[31 , "マジックチャージ", 2, 155, 107, 123, 134, 117, 0.4, 0], [32 , "バイオレイダー", 1, 178, 84, 133, 79, 92, 0.8, 0],
					[33 , "テクノドラゴン", 1, 132, 110, 100, 122, 105, 0.6, 0], [34 , "メガヒーロー", 0, 165, 71, 83, 121, 131, 0.8, 0],
					[35 , "プラズマテレポーター", 1, 147, 72, 85, 75, 90, 1, 0], [36 , "ナイトライダー", 1, 145, 114, 121, 106, 120, 0.4, 0],
					[37 , "ヒートウェーブ", 1, 178, 81, 85, 73, 89, 1, 0], [38 , "プラネットストライカー", 2, 151, 87, 107, 96, 118, 0.6, 0],
					[39 , "バードサイクロン", 1, 164, 124, 134, 80, 129, 0.2, 0], [40 , "フェイスクッカー", 0, 192, 80, 72, 84, 99, 0.8, 0],
					[41 , "ファイヤーバード", 0, 161, 135, 118, 110, 124, 0.2, 0], [42 , "バブルフューリー", 3, 158, 94, 111, 128, 72, 0.6, 0],
					[43 , "スカイブラスト", 0, 169, 70, 82, 134, 79, 0.8, 0], [44 , "マジックソード", 0, 159, 96, 113, 125, 121, 0.4, 0],
					[45 , "ベイブボーラー", 2, 175, 139, 140, 131, 94, 0.1, 0], [46 , "ロックスター", 1, 144, 93, 105, 85, 101, 0.8, 0],
					[47 , "バーチャルパワー", 0, 184, 107, 123, 137, 127, 0.2, 0], [48 , "ファイヤーフィスト", 1, 178, 137, 76, 90, 84, 0.6, 0],
					[49 , "メタルジャイアント", 0, 138, 108, 122, 113, 92, 0.6, 0], [50 , "ナイトライトドラゴン", 1, 181, 112, 128, 72, 88, 0.6, 0],
					[51 , "プラズマストーム", 1, 150, 116, 77, 99, 114, 0.6, 0], [52 , "ビッグバンガード", 1, 177, 118, 129, 124, 71, 0.4, 0],
					[53 , "バーニングナイト", 1, 188, 90, 86, 136, 81, 0.6, 0], [54 , "バブルウォーカー", 0, 169, 96, 108, 128, 123, 0.4, 0],
					[55 , "ブレイズフューリー", 3, 174, 81, 129, 73, 134, 0.6, 0], [56 , "ストームウォーカー", 1, 143, 87, 102, 119, 113, 0.8, 0],
					[57 , "スーパーバルカン", 1, 139, 95, 120, 137, 129, 0.4, 0], [58 , "バーチャルウォリアー", 4, 177, 86, 135, 131, 76, 0.6, 0],
					[59 , "ロックスティンガー", 1, 155, 113, 125, 72, 121, 0.4, 0], [60 , "プラネットソルジャー", 1, 182, 90, 80, 134, 84, 0.8, 0],
					[61 , "ストームシューター", 3, 164, 100, 135, 80, 96, 0.6, 0], [62 , "ファイヤービート", 1, 152, 124, 70, 125, 140, 0.4, 0],
					[63 , "ファイナルインパクト", 0, 130, 74, 140, 86, 101, 0.8, 0], [64 , "ヘヴィウェーブ", 0, 162, 96, 116, 134, 124, 0.4, 0],
					[65 , "ブレイクアウトバースト", 0, 171, 134, 79, 130, 74, 0.6, 0], [66 , "ヨネ", 5, 199, 90, 100, 150, 90, 0.2, 1],
					[67 , "ヒトシ", 5, 205, 100, 100, 140, 94, 0.2, 2], [68 , "はなえさん", 5, 162, 115, 122, 126, 151, 0.2, 3],
					[69 , "みっちー", 5, 187, 120, 100, 100, 120, 0.2, 4], [70 , "まさよん", 5, 205, 120, 100, 90, 100, 0.2, 5],
					[71 , "ヤングさん", 5, 195, 120, 105, 90, 100, 0.2, 6], [72 , "F澤", 5, 175, 110, 105, 110, 120, 0.2, 7],
					[73 , "Michael", 5, 184, 126, 80, 150, 95, 0.2, 8], [74 , "加護ちゃん", 5, 155, 180, 70, 121, 99, 0.2, 9],
					[75 , "かねちー", 5, 175, 110, 123, 107, 109, 0.2, 10], [76 , "はまりん", 5, 175, 90, 80, 120, 110, 0.2, 11],
					[77 , "上野東京ライン", 5, 170, 100, 115, 150, 70, 0.2, 12], [78 , "ヌマカツ", 5, 185, 125, 115, 120, 100, 0.2, 13],
					[79 , "情報の主：ヒサシ", 5, 225, 140, 140, 110, 150, 0.2, 14], [80, "泉を治めしもの", 5, 150, 100, 120, 80, 100, 0.1, 15]]
	
	#相性による倍率
	SETS_FIGHT = [[1, 1, 0.5, 1, 0.5, 0.5],
				[1, 0.5, 0.5, 1, 1, 0.5],
				[2, 1, 0.5, 1, 1, 0.5],
				[2, 1, 1, 0.5, 1, 0.5],
				[2, 1, 1, 1, 0.5, 1],
				[2, 2, 2, 2, 0.5, 0.5]]
	
	#通常技一覧
	TECH_NOMAL = [["暗記力", "数Ⅲ","NY研修マウント", "NY研修マウント", "1年から数Ⅲ"],
	[80, 70, 85, 75, 75]] #通常攻撃
	
	#特殊技一覧
	TECH_SPETIAL = [["一橋数学", "極限","憧れのブロードウェイ", "SG探究", "叫んでもいいですか?"],
	[90, 80, 70, 70, 90]]

	#個別技一覧
	TECH_INDIVIDUAL = [["意味考えて", "世界史の窓", "声の高低差", "見えない文字", "この問題燃えますね", "ヤングドーナツ", "攻撃するしかないんですよね？", "How many points?", "常夏フィーバー", "きのこしか勝たん", "エクロジャイト", "月見バーガー", "経済学", "音声増幅プログラム", "権限Lv.100"],
						  ["証明終了", "オピニオンシート", "すーぐスマホ触る", "なぁ、%", "センス'は'ありますよ", "地理難化", "凍り付く空気・ゑ？", "It's thinking time!", "真冬の半袖", "スペイン語の嵐", "ｺｹﾞﾝｰ", "ﾄﾞｽｶｯ、ﾄﾞｽｶｯ", "理転", "ね*100", "大雪登校"],
						  [80, 70, 90, 90, 90, 75, 90, 90, 80, 90, 80, 85, 90, 85, 120], 
						  [100, 100, 80, 80, 75, 90, 90, 100, 120, 90, 100, 130, 80, 100, 110]]
	
	#種族一覧
	RACE = ["文系", "理系", "SG文系", "SG理系", "理数科", "先生"]

	#ジムの相手(番地で指定)
	GYM_DEFAULT = [[0, 0, 0, 0, 0, 0],
				   [0, 0, 0, 0, 0, 0],
				   [0, 0, 0, 0, 0, 0],
				   [0, 0, 0, 0, 0, 0],
				   [0, 0, 0, 0, 0, 0],
				   [0, 0, 0, 0, 0, 0]]

	#ジムの名前
	GYM_DEFAULT_NAME = [["", ""],
		     			["", ""],
						["", ""],
						["", ""],
						["", ""],
						["", ""]]

	#レベル上限(番地とバッジの数 + 1が一致)
	LEVEL_MAX = [10, 20, 30, 40, 50, 60, 70]

	#レベルアップするのに必要な数
	LEVELUP_NUM = 5

	#パーティーの数
	PARTY_NUM = 6

	#区切り線の長さ
	SEPALATE_LEN = 50

	#特殊技の回数
	SPETIAL_NUM = 10

	#ダメージの期待値(Lv.50時)
	EXPECT_DAMAGE = 120

	#逃げれる確率
	ESCAPE_P = 0.8

	#敵選択
	IZMON_P = [0 , 1, 2, 3, 4, 5, 6, 7, 8, 9,
	    	   10,11,12,13,14,15,16,17,18,19,
			   20,21,22,23,24,25,26,27,28,29,
			   30,31,32,33,34,35,36,37,38,39,
			   40,41,42,43,44,45,46,47,48,49,
			   50,51,52,53,54,55,56,57,58,59,
			   60,61,62,63,64,65,66,66,67,67,
			   68,68,69,69,70,70,71,71,72,72,
			   73,73,74,74,75,75,76,76,77,77,
			   78,78,79,79,80,80]
	#敵選択のリストの要素数 - 1
	IZMON_P_LEN = 95

==> Izmon-1.0.0-py3-none-any.whl: Izmon/Class/Basic/Settings.py <==
class Settings:
	'''
	・CODE_CAP
	・PARTY_NUM
	・LEVELUP_NUM (桁数)
	・CODE_FELLOW_LEN
	以上の 4 定数の 'いずれか' を変更する際はコード と メジャーバージョンの変更が必要
	'''

	#バージョン
	VERSION = '1.0.0'
	
	#イズモンの数
	IZ_NUM = 80

	#イズモン設定一覧
	IZUMON_SETTING = [[1 , "サーファー", 0, 162, 80, 115, 153, 111, 0.4, 0], [2 , "キョーリュー", 0, 166, 154, 115, 120, 120, 0.2, 0],
					[3 , "ササントラ", 1, 167, 125, 110, 145, 110, 0.2, 0], [4 , "トラパルト", 2, 163, 140, 95, 120, 95, 0.2, 0],
					[5 , "マルルリ", 4, 175, 70, 100, 80, 100, 1, 0], [6 , "アーマー", 1, 173, 107, 125, 73, 105, 0.6, 0],
					[7 , "カブリアス", 0, 183, 150, 115, 100, 105, 0.1, 0], [8 , "マスダ", 4, 151, 130, 90, 101, 90, 0.4, 0],
					[9 , "ラウドホーン", 1, 179, 95, 120, 130, 95, 0.4, 0], [10 , "タイガイデヌ", 4, 145, 90, 80, 125, 80, 0.6, 0],
					[11 , "バッシュドラ", 0, 183, 132, 138, 88, 92, 0.4, 0], [12 , "プロキシー", 1, 170, 85, 130, 80, 150, 0.4, 0],
					[13 , "スプラッシュドラゴン", 3, 151, 167, 110, 80, 90, 0.4, 0], [14 , "ブラストロッキー", 2, 190, 165, 112, 95, 106, 0.2, 0],
					[15 , "マーダードラゴン", 1, 165, 120, 90, 130, 170, 0.2, 0], [16 , "スカイスパロー", 0, 178, 113, 87, 91, 81, 0.6, 0],
					[17 , "ファイアウォール", 4, 153, 101, 170, 94, 89, 0.4, 0], [18 , "バブルボーラー", 0, 135, 70, 90, 100, 100, 0.6, 0],
					[19 , "バニージャンプ", 0, 145, 100, 110, 90, 100, 0.6, 0], [20 , "スノースクーパー", 1, 136, 95, 120, 105, 120, 0.6, 0],
					[21 , "ラビットフライ", 0, 155, 115, 80, 90, 85, 0.6, 0], [22 , "スピードスター", 1, 135, 100, 95, 84, 70, 0.6, 0],
					[23 , "フライングホッパー", 1, 115, 110, 90, 100, 80, 0.8, 0], [24 , "スターフレイム", 1, 177, 71, 122, 141, 150, 0.4, 0],
					[25 , "プラネットポッター", 3, 138, 89, 109, 103, 115, 0.6, 0], [26 , "バイオレーサー", 2, 185, 79, 128, 149, 78, 0.4, 0],
					[27 , "スプラッシュファイター", 1, 186, 93, 83, 98, 116, 0.6, 0], [28 , "パルネアス", 4, 165, 140, 122, 112, 129, 0.1, 0],
					[29 , "ギガヴォルテック", 3, 178, 115, 132, 81, 124, 0.2, 0], [30 , "エンペラースライム", 4, 143, 78, 89, 106, 101, 0.8, 0],
					[31 , "マジックチャージ", 2, 155, 107, 123, 134, 117, 0.4, 0], [32 , "バイオレイダー", 1, 178, 84, 133, 79, 92, 0.8, 0],
					[33 , "テクノドラゴン", 1, 132, 110, 100, 122, 105, 0.6, 0], [34 , "メガヒーロー", 0, 165, 71, 83, 121, 131, 0.8, 0],
					[35 , "プラズマテレポーター", 1, 147, 72, 85, 75, 90, 1, 0], [36 , "ナイトライダー", 1, 145, 114, 121, 106, 120, 0.4, 0],
					[37 , "ヒートウェーブ", 1, 178, 81, 85, 73, 89, 1, 0], [38 , "プラネットストライカー", 2, 151, 87, 107, 96, 118, 0.6, 0],
					[39 , "バードサイクロン", 1, 164, 124, 134, 80, 129, 0.2, 0], [40 , "フェイスクッカー", 0, 192, 80, 72, 84, 99, 0.8, 0],
					[41 , "ファイヤーバード", 0, 161, 135, 118, 110, 124, 0.2, 0], [42 , "バブルフューリー", 3, 158, 94, 111, 128, 72, 0.6, 0],
					[43 , "スカイブラスト", 0, 169, 70, 82, 134, 79, 0.8, 0], [44 , "マジックソード", 0, 159, 96, 113, 125, 121, 0.4, 0],
					[45 , "ベイブボーラー", 2, 175, 139, 140, 131, 94, 0.1, 0], [46 , "ロックスター", 1, 144, 93, 105, 85, 101, 0.8, 0],
					[47 , "バーチャルパワー", 0, 184, 107, 123, 137, 127, 0.2, 0], [48 , "ファイヤーフィスト", 1, 178, 137, 76, 90, 84, 0.6, 0],
					[49 , "メタルジャイアント", 0, 138, 108, 122, 113, 92, 0.6, 0], [50 , "ナイトライトドラゴン", 1, 181, 112, 128, 72, 88, 0.6, 0],
					[51 , "プラズマストーム", 1, 150, 116, 77, 99, 114, 0.6, 0], [52 , "ビッグバンガード", 1, 177, 118, 129, 124, 71, 0.4, 0],
					[53 , "バーニングナイト", 1, 188, 90, 86, 136, 81, 0.6, 0], [54 , "バブルウォーカー", 0, 169, 96, 108, 128, 123, 0.4, 0],
					[55 , "ブレイズフューリー", 3, 174, 81, 129, 73, 134, 0.6, 0], [56 , "ストームウォーカー", 1, 143, 87, 102, 119, 113, 0.8, 0],
					[57 , "スーパーバルカン", 1, 139, 95, 120, 137, 129, 0.4, 0], [58 , "バーチャルウォリアー", 4, 177, 86, 135, 131, 76, 0.6, 0],
					[59 , "ロックスティンガー", 1, 155, 113, 125, 72, 121, 0.4, 0], [60 , "プラネットソルジャー", 1, 182, 90, 80, 134, 84, 0.8, 0],
					[61 , "ストームシューター", 3, 164, 100, 135, 80, 96, 0.6, 0], [62 , "ファイヤービート", 1, 152, 124, 70, 125, 140, 0.4, 0],
					[63 , "ファイナルインパクト", 0, 130, 74, 140, 86, 101, 0.8, 0], [64 , "ヘヴィウェーブ", 0, 162, 96, 116, 134, 124, 0.4, 0],
					[65 , "ブレイクアウトバースト", 0, 171, 134, 79, 130, 74, 0.6, 0], [66 , "ヨネ", 5, 199, 90, 100, 150, 90, 0.2, 1],
					[67 , "ヒトシ", 5, 205, 100, 100, 140, 94, 0.2, 2], [68 , "はなえさん", 5, 162, 115, 122, 126, 151, 0.2, 3],
					[69 , "みっちー", 5, 187, 120, 100, 100, 120, 0.2, 4], [70 , "まさよん", 5, 205, 120, 100, 90, 100, 0.2, 5],
					[71 , "ヤングさん", 5, 195, 120, 105, 90, 100, 0.2, 6], [72 , "F澤", 5, 175, 110, 105, 110, 120, 0.2, 7],
					[73 , "Michael", 5, 184, 126, 80, 150, 95, 0.2, 8], [74 , "加護ちゃん", 5, 155, 180, 70, 121, 99, 0.2, 9],
					[75 , "かねちー", 5, 175, 110, 123, 107, 109, 0.2, 10], [76 , "はまりん", 5, 175, 90, 80, 120, 110, 0.2, 11],
					[77 , "上野東京ライン", 5, 170, 100, 115, 150, 70, 0.2, 12], [78 , "ヌマカツ", 5, 185, 125, 115, 120, 100, 0.2, 13],
					[79 , "情報の主：ヒサシ", 5, 225, 140, 140, 110, 150, 0.2, 14], [80, "泉を治めしもの", 5, 150, 100, 120, 80, 100, 0.1, 15]]
	
	#相性による倍率
	SETS_FIGHT = [[1, 1, 0.5, 1, 0.5, 0.5],
				[1, 0.5, 0.5, 1, 1, 0.5],
				[2, 1, 0.5, 1, 1, 0.5],
				[2, 1, 1, 0.5, 1, 0.5],
				[2, 1, 1, 1, 0.5, 1],
				[2, 2, 2, 2, 0.5, 0.5]]
	
	#通常技一覧
	TECH_NOMAL = [["暗記力", "数Ⅲ","NY研修マウント", "NY研修マウント", "1年から数Ⅲ"],
	[80, 70, 85, 75, 75]] #通常攻撃
	
	#特殊技一覧
	TECH_SPETIAL = [["一橋数学", "極限","憧れのブロードウェイ", "SG探究", "叫んでもいいですか?"],
	[90, 80, 70, 70, 90]]

	#個別技一覧
	TECH_INDIVIDUAL = [["意味考えて", "世界史の窓", "声の高低差", "見えない文字", "この問題燃えますね", "ヤングドーナツ", "攻撃するしかないんですよね？", "How many points?", "常夏フィーバー", "きのこしか勝たん", "エクロジャイト", "月見バーガー", "経済学", "音声増幅プログラム", "権限Lv.100"],
						  ["証明終了", "オピニオンシート", "すーぐスマホ触る", "なぁ、%", "センス'は'ありますよ", "地理難化", "凍り付く空気・ゑ？", "It's thinking time!", "真冬の半袖", "スペイン語の嵐", "ｺｹﾞﾝｰ", "ﾄﾞｽｶｯ、ﾄﾞｽｶｯ", "理転", "ね*100", "大雪登校"],
						  [80, 70, 90, 90, 90, 75, 90, 90, 80, 90, 80, 85, 90, 85, 120], 
						  [100, 100, 80, 80, 75, 90, 90, 100, 120, 90, 100, 130, 80, 100, 110]]
	
	#種族一覧
	RACE = ["文系", "理系", "SG文系", "SG理系", "理数科", "先生"]

	#ジムの相手(番号で指定)
	GYM_DEFAULT = [[40, 1, 11, 7, 16],
				   [53, 3, 36, 48, 27],
				   [55, 25, 13, 25, 29],
				   [26, 4, 31, 38, 14],
				   [28, 5, 10, 30, 58],
				   [80, 78, 73, 75, 79]]
	
	#ジムの名前
	GYM_DEFAULT_NAME = [["一橋大学", "歩く六法全書"],
		     			["東京大学", "理さん"],
						["ホワイトハウス", "Ms. Baker"],
						["タイムズスクエア", "SGの神：スズモリ"],
						["シリコンバレー", "初代パル"],
						["教育委員会", "教育委員長"]]

	#レベル上限(番地とバッジの数 + 1が一致)
	LEVEL_MAX = [10, 20, 30, 40, 50, 60, 70]

	#レベルアップするのに必要な数
	LEVELUP_NUM = 5

	#パーティーの数
	PARTY_NUM = 6

	#区切り線の長さ
	SEPALATE_LEN = 50

	#特殊技の回数
	SPETIAL_NUM = 10

	#ダメージの期待値(Lv.50時)
	EXPECT_DAMAGE = 120

	#逃げれる確率
	ESCAPE_P = 0.8

	#敵選択
	IZMON_P = [0 , 1, 2, 3, 4, 5, 6, 7, 8, 9,
	    	   10,11,12,13,14,15,16,17,18,19,
			   20,21,22,23,24,25,26,27,28,29,
			   30,31,32,33,34,35,36,37,38,39,
			   40,41,42,43,44,45,46,47,48,49,
			   50,51,52,53,54,55,56,57,58,59,
			   60,61,62,63,64,65,66,66,67,67,
			   68,68,69,69,70,70,71,71,72,72,
			   73,73,74,74,75,75,76,76,77,77,
			   78,78,79,79,80,80]
	#敵選択のリストの要素数 - 1
	IZMON_P_LEN = 95

	#データの保存の際の桁数
	CODE_CAP = 100

	#10進数に仲間のデータを変換した時の桁数
	CODE_FELLOW_LEN = 31
